@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.1 1999/11/22 18:26:16 bazsi Exp $
+ * $Id: afinet.c,v 1.3 1999/11/23 19:45:45 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -64,10 +64,12 @@ do_init_afinet_source_connection(struct log_handler *c,
 				 struct persistent_config *persistent)
 {
 	CAST(afsocket_source_connection, self, c);
-	CAST(inet_address_info, inet, self->client_addr);
-
-	notice("AF_INET client connected from %S, port %i\n", 
-	       inet->ip, inet->port);
+	if (self->client_addr) {
+		CAST(inet_address_info, inet, self->client_addr);
+		
+		notice("AF_INET client connected from %S, port %i\n", 
+		       inet->ip, inet->port);
+	}
 	io_read(self->client, 
 		make_log_reader(1, c), 
 		make_afsocket_source_close_callback(self));
@@ -90,10 +92,13 @@ static int
 do_close_afinet_connection(struct afsocket_source_connection *c,
                            int close_reason)
 {
-	CAST(inet_address_info, inet, c->client_addr);
 	assert(c->owner);
-	notice("AF_INET client dropped connection from %S, port %i\n", 
-	       inet->ip, inet->port);
+	if (c->client_addr) {
+		CAST(inet_address_info, inet, c->client_addr);
+
+		notice("AF_INET client dropped connection from %S, port %i\n", 
+		       inet->ip, inet->port);
+	}
 	object_queue_remove(c->queue_node);
 	c->owner->num_connections--;
 	return ST_OK | ST_GOON;
