@@ -42,6 +42,8 @@
 char cfgfilename[128] = PATH_SYSLOG_NG_CONF;
 char pidfilename[128] = PATH_PIDFILE;
 
+int restarting = 0;
+
 /* CLASS:
    (class
      (name reread_config)
@@ -72,6 +74,7 @@ static void do_reread_config(struct callback *c)
 			self->backend->oldconfig = NULL;
 			kill_persistent_config(self->backend->persistent);
 			self->backend->persistent = NULL;
+			restarting = 0;
 		}
 		else {
 			/* initializing the new configuration was not 
@@ -93,6 +96,7 @@ static void do_reread_config(struct callback *c)
 		}
 		kill_persistent_config(self->backend->persistent);
 		self->backend->persistent = NULL;
+		restarting = 0;
 		break;
 	}
 }
@@ -135,9 +139,10 @@ int main_loop(struct syslog_backend *backend)
 	while (io_iter(&backend->super)) {
 		if (exit_main_loop)
 			break;
-		if (sighuprecvd) {
+		if (sighuprecvd && !restarting) {
 
 			notice("SIGHUP received, restarting syslog-ng\n");
+			restarting = 1;
 			backend->newconfig = make_syslog_config(cfgfilename, &backend->super);
 			if (backend->newconfig) {
 				static struct reread_config r = 
@@ -157,6 +162,10 @@ int main_loop(struct syslog_backend *backend)
 			exit_main_loop = 1;
 		}
 	}
+	if (!exit_main_loop) {
+		notice("No input/output channels opened, exiting...\n");
+		CONFIG_DESTROY(backend->configuration, 0);
+	}
 	return 0;
 }
 
